<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN" sourcelanguage="zh_CN">
<context>
    <name>MainWindow</name>
    <message>
        <source>Basic Downloader</source>
        <translation>基础下载</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Get List</source>
        <translation>获取画质列表</translation>
    </message>
    <message>
        <source>Enter URL:</source>
        <translation>输入视频网址:</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>下载</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>画质选项</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>格式代码</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>扩展</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>分辨率</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>提示</translation>
    </message>
    <message>
        <source>Engine Name:</source>
        <translation>引擎名称:</translation>
    </message>
    <message>
        <source>Paste Clipboard Content</source>
        <translation>粘贴剪贴板内容</translation>
    </message>
    <message>
        <source>Recently Used</source>
        <translation>最近使用</translation>
    </message>
    <message>
        <source>Set Download Options</source>
        <translation>设置下载选项</translation>
    </message>
    <message>
        <source>Batch Downloader</source>
        <translation>批量下载</translation>
    </message>
    <message>
        <source>Thumbnail</source>
        <translation>缩略图</translation>
    </message>
    <message>
        <source>Url To Download</source>
        <translation>下载网址列表</translation>
    </message>
    <message>
        <source>Paste Clipboard Url</source>
        <translation>粘贴剪贴板网址</translation>
    </message>
    <message>
        <source>Monitor Clipboard For Url</source>
        <translation>监视剪贴板网址</translation>
    </message>
    <message>
        <source>Add Url To List</source>
        <translation>添加网址到列表</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Playlist Downloader</source>
        <translation>播放列表下载</translation>
    </message>
    <message>
        <source>Download Options:</source>
        <translation>下载选项:</translation>
    </message>
    <message>
        <source>Time Interval Start Time(HH:MM:SS):</source>
        <translation>时间间隔 开始时间(HH:MM:SS):</translation>
    </message>
    <message>
        <source>Time Interval End Time(HH:MM:SS):</source>
        <translation>时间间隔 结束时间(HH:MM:SS):</translation>
    </message>
    <message>
        <source>Chapters(Comma Separated):</source>
        <translation>章节(英文逗号分隔):</translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation>按章节划分</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>隐藏</translation>
    </message>
    <message>
        <source>Enter Playlist URL:</source>
        <translation>输入播放列表网址:</translation>
    </message>
    <message>
        <source>Clear Internal Archive File</source>
        <translation>清除内部存档文件</translation>
    </message>
    <message>
        <source>Use Internal Archive File</source>
        <translation>使用内部存档文件</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>库</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>类型</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>向上</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>刷新</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>打开文件夹</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>主页</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>配置</translation>
    </message>
    <message>
        <source>General Options</source>
        <translation>常规设置</translation>
    </message>
    <message>
        <source>Show Tray Icon</source>
        <translation>显示托盘图标</translation>
    </message>
    <message>
        <source>Auto Save List Of Not Downloaded Media</source>
        <translation>自动保存未下载媒体列表</translation>
    </message>
    <message>
        <source>Auto Hide Downloads When Completed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Option To Its Default</source>
        <translation>将选项重置为默认值</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation>设置为默认值</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>预设画质选项</translation>
    </message>
    <message>
        <source>Download Path</source>
        <translation>下载文件路径</translation>
    </message>
    <message>
        <source>Select Language</source>
        <translation>选择语言</translation>
    </message>
    <message>
        <source>Use Manually Specified Proxy Configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get Proxy Configuration From The Environment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Proxy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Engine&apos;s Default Options</source>
        <translation>引擎默认选项</translation>
    </message>
    <message>
        <source>File Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>获取列表选项:</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>订阅</translation>
    </message>
    <message>
        <source>Ui Name</source>
        <translation>分辨率名称</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>添加</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>网址</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <source>Enable Library Tab</source>
        <translation>启用库选项</translation>
    </message>
    <message>
        <source>Maximum Concurrent Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation>文本编码</translation>
    </message>
    <message>
        <source>Show Version Info And Autodownload Updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Version Info And Latest Version Info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Version Info Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do Nothing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Actions At Startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Website</source>
        <translation>网站</translation>
    </message>
    <message>
        <source>Engine&apos;s Name</source>
        <translation>引擎名称</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>默认</translation>
    </message>
    <message>
        <source>Options To Add</source>
        <translation>添加选项</translation>
    </message>
    <message>
        <source>Url Manager</source>
        <translation>网址管理</translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>下载选项</translation>
    </message>
    <message>
        <source>Set What Url Should Be Managed By What Engine</source>
        <translation>设置哪个引擎应该管理哪个网址</translation>
    </message>
    <message>
        <source>Url Filter</source>
        <translation>网址过滤</translation>
    </message>
    <message>
        <source>Proxy Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use System Proxy Configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manually Specified Proxy Configuration
Example 1: 192.168.93.89:8080
Exampe 2: ${gateway}:8080</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <source>Play Downloaded Media</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter Playlist Url. To Add Multiple Playlists, Separate Them With A Space Or New Line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A Button To Open A Folder To Be Used As A Download Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Theme Config Files Are Stored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Extension&apos;s Binaries Are Stored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are You Sure You Want To Reset These Options To Their Defaults?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme(Need A Restart)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch Between Setting Browser Name And Path To Cookie File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show MetaData In Batch Downloader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto Download Added Entries In Batch Downloader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify When Download Completes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify When All Downloads Complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Engine&apos;s Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove An Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update An Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add An Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Binary Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Extension Folder</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 Preset Options</source>
        <translation>%1 预设选项</translation>
    </message>
    <message>
        <source>Filename with &quot;.txt&quot; Extension Will Save Urls Only</source>
        <translation> 文件名带有&quot;.txt&quot;的扩展程序将仅保存网址</translation>
    </message>
    <message>
        <source>Hide Row</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unhide All Hidden Rows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Start Executable %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation type="unfinished">复制网址</translation>
    </message>
    <message>
        <source>Open Url With %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Url %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save List To File</source>
        <translation>保存列表到文件</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    <message>
        <source>Replies to</source>
        <translation>回复</translation>
    </message>
    <message>
        <source>Save Subtitle To File</source>
        <translation>将字幕保存到文件</translation>
    </message>
    <message>
        <source>Engine Name:</source>
        <translation>引擎名称:</translation>
    </message>
    <message>
        <source>Get List From File</source>
        <translation>从文件从获取列表</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>预设的画质选项</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>清除</translation>
    </message>
    <message>
        <source>Open Download Folder</source>
        <translation>打开下载文件夹</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>版本</translation>
    </message>
    <message>
        <source>Project Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation>版权</translation>
    </message>
    <message>
        <source>License</source>
        <translation>许可协议</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>电子邮箱</translation>
    </message>
    <message>
        <source>Qt Version</source>
        <translation>Qt版本</translation>
    </message>
    <message>
        <source>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.</source>
        <translation>该程序是免费软件; 您可以根据自由软件基金会发布的 GNU 通用公共许可证的条款重新分发和/或修改它; 许可证的版本 2 或(由您选择)任何更高版本.</translation>
    </message>
    <message>
        <source>This program is distributed in the hope that it will be useful,but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.</source>
        <translation>分发此程序是希望它有用,但不提供任何保证;甚至没有适销性或特定用途适用性的默示保证.有关更多详细信息,请参阅 GNU 通用公共许可证.</translation>
    </message>
    <message>
        <source>Polish (Poland)</source>
        <translation>波兰语 (波兰)</translation>
    </message>
    <message>
        <source>English (US)</source>
        <translation>英语 (美国)</translation>
    </message>
    <message>
        <source>Spanish (Spain)</source>
        <translation>西班牙语 (西班牙)</translation>
    </message>
    <message>
        <source>Chinese (China)</source>
        <translation>中文 (中国)</translation>
    </message>
    <message>
        <source>Turkish (Turkey)</source>
        <translation>土耳其语 (土耳其)</translation>
    </message>
    <message>
        <source>Russian (Russia)</source>
        <translation>俄语 (俄罗斯)</translation>
    </message>
    <message>
        <source>Japanese (Japan)</source>
        <translation>日语 (日本)</translation>
    </message>
    <message>
        <source>French (France)</source>
        <translation>法语 (法国)</translation>
    </message>
    <message>
        <source>Italian (Italy)</source>
        <translation>意大利语 (意大利)</translation>
    </message>
    <message>
        <source>Swedish (Sweden)</source>
        <translation>瑞典语 (瑞典)</translation>
    </message>
    <message>
        <source>German (Germany)</source>
        <translation>德语 (德国)</translation>
    </message>
    <message>
        <source>Portuguese (Brazil)</source>
        <translation>葡萄牙语 (巴西)</translation>
    </message>
    <message>
        <source>Dutch (Netherlands)</source>
        <translation>荷兰语 (荷兰)</translation>
    </message>
    <message>
        <source>Error, executable to backend &quot;%1&quot; could not be found</source>
        <translation>错误,找不到后端的可执行文件&quot;%1&quot;</translation>
    </message>
    <message>
        <source>Engine &quot;%1&quot; requires atleast version &quot;%2&quot; of Media Downloader</source>
        <translation>引擎&quot;%1&quot; 至少需要Media Downloader版本&quot;%2&quot;</translation>
    </message>
    <message>
        <source>To Disable These Checks, Do The Following:-</source>
        <translation>要禁用这些检查,请执行以下操作:-</translation>
    </message>
    <message>
        <source>1. Go To &quot;Configure&quot; Tab.</source>
        <translation>1. 转到&quot;配置&quot;选项.</translation>
    </message>
    <message>
        <source>2. Go To &quot;General Options&quot; Sub Tab.</source>
        <translation>2. 转到&quot;常规选项&quot;子选项卡.</translation>
    </message>
    <message>
        <source>3. Click &quot;Actions At StartUp&quot; Menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4. Select &quot;Do Nothing&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Running In Portable Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Running In Installation Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Path: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>App Data Path: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Setting Proxy Server Address Of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsetting Proxy Server Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error, failed to parse config file &quot;%1&quot;</source>
        <translation>错误,无法解析配置文件&quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed To Load A Plugin</source>
        <translation>插件加载失败</translation>
    </message>
    <message>
        <source>Failed to find executable &quot;%1&quot;</source>
        <translation>找不到可执行文件&quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed to find python3 executable for backend &quot;%1&quot;</source>
        <translation>找不到后端的python3可执行文件&quot;%1&quot;</translation>
    </message>
    <message>
        <source>Network Error Occured</source>
        <translation>发生网络错误</translation>
    </message>
    <message>
        <source>Url Is Not Supported</source>
        <translation>网址不受支持</translation>
    </message>
    <message>
        <source>Download cancelled</source>
        <translation>下载已取消</translation>
    </message>
    <message>
        <source>ErrorCode</source>
        <translation>错误代码</translation>
    </message>
    <message>
        <source>Download Failed, Engine failed to start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Failed, Engine crashed</source>
        <translation>下载失败,引擎崩溃</translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>格式代码</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>扩展</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>分辨率</translation>
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Note</source>
        <translation>提示</translation>
    </message>
    <message>
        <source>Failed to open file for writing</source>
        <translation>无法打开文件进行写入</translation>
    </message>
    <message>
        <source>Failed to open file for reading</source>
        <translation>无法打开文件进行读取</translation>
    </message>
    <message>
        <source>Elapsed Time:</source>
        <translation>已用时间:</translation>
    </message>
    <message>
        <source>Failed to find version information, make sure &quot;%1&quot; is installed and works properly</source>
        <translation>未能找到版本信息,请确保&quot;%1&quot;已安装并且正常工作</translation>
    </message>
    <message>
        <source>Found version</source>
        <translation>找到的版本</translation>
    </message>
    <message>
        <source>Failed To Open Path For Writing: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Extract</source>
        <translation>提取失败</translation>
    </message>
    <message>
        <source>Network Failed To Respond Within %1 seconds</source>
        <translation>网络未能在 %1 秒内响应</translation>
    </message>
    <message>
        <source>Failed to download, Following path can not be created: </source>
        <translation>下载失败,无法创建以下路径: </translation>
    </message>
    <message>
        <source>Start Downloading</source>
        <translation>开始下载</translation>
    </message>
    <message>
        <source>Trouble Ahead, Failed To Delete Folder: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Find &quot;bsdtar.exe&quot; Executable</source>
        <translation>无法找到&quot;bsdtar.exe&quot;可执行文件</translation>
    </message>
    <message>
        <source>Download Failed</source>
        <translation>下载失败</translation>
    </message>
    <message>
        <source>Failed to parse json file from github</source>
        <translation>无法从github解析json文件</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>下载中</translation>
    </message>
    <message>
        <source>Destination</source>
        <translation>目标地址</translation>
    </message>
    <message>
        <source>Update Complete, Restart To Use New Version</source>
        <translation>更新完成,重启即可使用新版本</translation>
    </message>
    <message>
        <source>Windows&apos; Secure Channel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File Not Found</source>
        <translation>文件未找到</translation>
    </message>
    <message>
        <source>Download complete</source>
        <translation>下载完成</translation>
    </message>
    <message>
        <source>Extracting archive: </source>
        <translation>提取存档: </translation>
    </message>
    <message>
        <source>Processing</source>
        <translation>处理中</translation>
    </message>
    <message>
        <source>Download completed</source>
        <translation>下载已完成</translation>
    </message>
    <message>
        <source>Resetting download folder to default</source>
        <translation>正在将下载文件夹重置为默认文件夹</translation>
    </message>
    <message>
        <source>Post Processing</source>
        <translation>后期处理</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>下载</translation>
    </message>
    <message>
        <source>Force Download</source>
        <translation>强制下载</translation>
    </message>
    <message>
        <source>Show Log Window</source>
        <translation>显示日志窗口</translation>
    </message>
    <message>
        <source>Upload Date:</source>
        <translation>上传日期:</translation>
    </message>
    <message>
        <source>Duration:</source>
        <translation>持续时间:</translation>
    </message>
    <message>
        <source>Subtitle Name</source>
        <translation>字幕名称</translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>下载选项</translation>
    </message>
    <message>
        <source>Extra Downloading Options</source>
        <translation>额外的下载选项</translation>
    </message>
    <message>
        <source>Download Time Interval</source>
        <translation>下载时间间隔</translation>
    </message>
    <message>
        <source>Download Chapters</source>
        <translation>下载章节</translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation>按章节划分</translation>
    </message>
    <message>
        <source>Media Already In Archive</source>
        <translation>已存档的媒体</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>黑暗</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>模式</translation>
    </message>
    <message>
        <source>Time Left</source>
        <translation>剩余时间</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>已下载</translation>
    </message>
    <message>
        <source>%1 Already Downloaded</source>
        <translation>%1 已下载</translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation>这可能需要很长时间</translation>
    </message>
    <message>
        <source>Speed:</source>
        <translation>速度:</translation>
    </message>
    <message>
        <source>There Is An Update For %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Newest Version Is %1, Updating</source>
        <translation>最新版本是 %1,正在更新</translation>
    </message>
    <message>
        <source>Checking installed version of %1</source>
        <translation>检查已安装的 %1 版本</translation>
    </message>
    <message>
        <source>Found version: %1</source>
        <translation>找到的版本: %1 </translation>
    </message>
    <message>
        <source>Newest Version Is: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please Update &quot;%1&quot; To Atleast Version &quot;%2&quot;</source>
        <translation>请更新&quot;%1&quot;至少到版本&quot;%2&quot;</translation>
    </message>
    <message>
        <source>Requested Format Is Not Available</source>
        <translation>请求的格式不可用</translation>
    </message>
    <message>
        <source>Invalid Url Entered</source>
        <translation>输入的网址无效</translation>
    </message>
    <message>
        <source>Best Available Audio Only</source>
        <translation>仅最佳可用音频</translation>
    </message>
    <message>
        <source>Best Available Audio Only(MP3)</source>
        <translation>最佳可用音频(MP3)</translation>
    </message>
    <message>
        <source>Best Available Audio Video</source>
        <translation>最佳可用音频视频</translation>
    </message>
    <message>
        <source>Best Audio With Video Resolution Of %1</source>
        <translation>视频分辨率为 %1 的最佳音频</translation>
    </message>
    <message>
        <source>Warning: Skipping Clipboard Content</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Folders First</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arrange In Ascending Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arrange By Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arrange By Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arrange In Descending Order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Filter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other Websites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extract Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extract Audio As MP3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arabic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Best Available Audio Only+Thumbnail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Youtube</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Autoupdate Disabled For %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Newest Version Is %1, AutoUpdate Disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Author: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Like Count: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Korean (Korea)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sign In To Confirm You Are Not A Bot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show/Hide Controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Merging Audio and Video Together</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remuxing video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Greek (Greece)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Platform Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Completed: %1, Running: %2, Not Started: %3, Succeeded: %4, Failed: %5, Cancelled: %6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stopping Because Media Is Already In Archive File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bulgarien (Bulgaria)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Urls With %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning, Nothing Was Downloaded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Cancelled, Playlist Urls Are Not Allowed In This Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Cancelled Because A Condition Was Not Met</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Failed, Unknown Reason</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Failed, Network Issue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ukrainian (Ukraine)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming &quot;%1&quot; to &quot;%2&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming Failed: %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skipping Checking Download Hash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignoring Download Because Hashes Do Not Match</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expected &quot;%1&quot; but obtained &quot;%2&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming file to: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Find &quot;bsdtar&quot; Executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skipping Checking Version Info For Engine &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>basicdownloader</name>
    <message>
        <source>Hide List</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>batchdownloader</name>
    <message>
        <source>Set Batch File</source>
        <translation>选择批量下载地址的文件</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <source>Downloading comments</source>
        <translation>正在下载评论</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>下载</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>复制网址</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <source>Show Subtitles</source>
        <translation>显示字幕</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>显示评论</translation>
    </message>
    <message>
        <source>Show Media Options</source>
        <translation>显示媒体设置</translation>
    </message>
    <message>
        <source>Download Media Part</source>
        <translation>下载媒体部分</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>Downloading subtitles</source>
        <translation>下载字幕</translation>
    </message>
    <message>
        <source>Sort By Date Ascending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort By Date Descending</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sort By Likes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Set As Default</source>
        <translation>设为默认</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <source>Select An Engine File</source>
        <translation>选择引擎文件</translation>
    </message>
    <message>
        <source>Set Download Folder</source>
        <translation>选择下载文件夹</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished">添加</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation type="unfinished">设置为默认值</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">取消</translation>
    </message>
    <message>
        <source>Select A Cookie File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Path To Cookie File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>library</name>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>全部删除</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below File?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below Folder?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">取消</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete All Files And Folders?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename Folder To Below Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Selected Items?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>logWindow</name>
    <message>
        <source>Log Window</source>
        <translation>日志窗口</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>清除</translation>
    </message>
</context>
<context>
    <name>playlistdownloader</name>
    <message>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <source>Hide Controls</source>
        <translation>隐藏控件</translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>获取列表选项:</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>复制网址</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>显示评论</translation>
    </message>
    <message>
        <source>Show All Updated</source>
        <translation>显示所有更新</translation>
    </message>
    <message>
        <source>Download All Updated</source>
        <translation>下载所有更新</translation>
    </message>
    <message>
        <source>Manage Subscriptions</source>
        <translation>管理订阅</translation>
    </message>
    <message>
        <source>Number of Pages Downloaded</source>
        <translation>下载页数</translation>
    </message>
    <message>
        <source>Downloading video info</source>
        <translation>下载视频信息</translation>
    </message>
    <message>
        <source>Show Controls</source>
        <translation>显示控件</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>显示</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>隐藏</translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation>这可能需要很长时间</translation>
    </message>
</context>
</TS>
